@@ -181,6 +181,11 @@
 			@return Object value
 		*/
 		function getColValue($iRow_=0) {
+			// if it's a command, run and return an empty string
+			if($this->_sType=="CMD"){ 
+				$this->availExpr($this->_sExpr);
+				return "";
+			}
 			$sBookmark = "";
 			$sLinkOpen = "";
 			$sLinkClose= "";
@@ -251,11 +256,14 @@
 				
 			// if its not null and have some special stuff on it 	
 			if(!is_null($this->_oCurVal)) {
-				// number format
-				if(!is_null($this->_sNform))	
-					$this->_oCurVal = sprintf($this->_sNform,$this->_oCurVal);
+				// number format exists
+				if(!is_null($this->_sNform)){	
+					// needs to be a string or a numeric value to apply the formatting 
+					if(strpos($this->_sNform,"%s") || is_numeric($this->_oCurVal))
+						$this->_oCurVal = sprintf($this->_sNform,$this->_oCurVal);
+				}
 				// number format extended
-				if($this->_iNformX>0)
+				if($this->_iNformX>=0 && is_numeric($this->_oCurVal))
 					$this->_oCurVal = number_format($this->_oCurVal,$this->_iNformX,$this->_sDecSep,$this->_sThoSep);	
 			}
 			return $this->_oCurVal;
@@ -268,8 +276,6 @@
 		function availValue($sExpr_=null){
 			if(is_null($sExpr_))
 				return $sExpr_;
-			$header	=& $this;
-			$oValue	=& $this;
 
 			if($this->_sType=="EXPRESSION") 
 				return htmlspecialchars($this->availExpr($sExpr_),ENT_NOQUOTES);
@@ -288,8 +294,6 @@
 		function availExpr($sExpr_=null){
 			if(is_null($sExpr_))
 				return $sExpr_;
-			$header	=& $this;
-			$oValue	=& $this;
 			return eval($sExpr_);	
 		}
 		
@@ -343,6 +347,15 @@
 			return $oPage->getPageNum();
 		}
 		
+		function setPageNum($iNum_=0) {
+			$oPage =& $this->_oGroup->getPage();
+			return $oPage->setPageNum($iNum_);
+		}
+
+		function resetPageNum(){
+			return $this->setPageNum(0);
+		}
+		
 		/**
 			Sets the column group
 			@param Object group
