@@ -245,7 +245,7 @@
 		function &getPage() {
 			$oPage=null;
 			if(get_class($this)=="phpreportpage")
-				$oPage =& $this;
+				return $this;
 			else {				
 				if(!isset($this->_oReport)) {
 					print "REPORT ELEMENT IS NOT OK (".$this->getName().")<br>";
@@ -562,6 +562,10 @@
 						$oPage->eventHandler(PAGE_OPEN);
 						return;
 					}
+
+					if($this->isResetingSuppress()) 
+						$this->resetOldValues();
+
 					$this->printHeader();	
 
 					if(!is_null($this->_oChild)) {
