@@ -42,6 +42,8 @@
 		var $_sClassName;		// report class name to create
 		var $_sTmp;				// temporary dir
 		var $_oCon;				// database connection handle
+		var $_iPageSize;		// page size
+		var $_aBench;			// benchmark registers
 
 		/***************************************************************************
 		*																									*
@@ -65,11 +67,14 @@
 			$this->sOut					= null;		
 			$this->bDebug				= false;
 			$this->_sNoDataMsg		= "";
+			$this->_sNoDataFunc		= "";
 			$this->_sOutputPlugin	= "default";
 			$this->_oOutputPlugin	= null;
 			$this->_sSaveTo			= null;
 			$this->_aEnv				= Array();
 			$this->_sClassName		= "PHPReport";
+			$this->_iPageSize			= 0;
+			$this->_aBench				= Array();
 
 			/*
 				Now we get the XSLT processor
@@ -96,15 +101,19 @@
 		*																										*
 		******************************************************************************/
 		function run() {
+			$iReportStart = time();
+
 			// create the parameters array
-			$aParm["user"     ] = $this->sUser;				// set user
-			$aParm["pass"     ] = $this->sPass;				// set password
-			$aParm["conn"     ] = $this->sCon;				// set connection name
-			$aParm["interface"] = $this->sDataI;			// set database interface
-			$aParm["database" ] = $this->sDatabase;		// set database
-			$aParm["classname"] = $this->_sClassName;		// ALWAYS use this class to run the report
-			$aParm["sql"      ] = $this->sSQL;				// set the sql query
-			$aParm["nodatamsg"] = $this->_sNoDataMsg;		// no data msg
+			$aParm["user"     ]	= $this->sUser;			// set user
+			$aParm["pass"     ]	= $this->sPass;			// set password
+			$aParm["conn"     ]	= $this->sCon;				// set connection name
+			$aParm["interface"]	= $this->sDataI;			// set database interface
+			$aParm["database" ]	= $this->sDatabase;		// set database
+			$aParm["classname"]	= $this->_sClassName;	// ALWAYS use this class to run the report
+			$aParm["sql"      ]	= $this->sSQL;				// set the sql query
+			$aParm["nodatamsg"]	= $this->_sNoDataMsg;	// no data msg
+			$aParm["nodatafunc"] = $this->_sNoDataFunc;	// no data function
+			$aParm["pagesize"]	= $this->_iPageSize>0?$this->_iPageSize:"";							
 
 			// create the parameters keys array - with element numbers or element keys
 			$aKeys = null;
@@ -137,12 +146,15 @@
 			}
 
 			// XSLT processing
+			$this->_aBench["code_start"] = time();
 			$this->_oProc->setXML($this->sXML);
 			$this->_oProc->setXSLT($this->sXSLT);
 			$this->_oProc->setOutput($sOut);
 			$this->_oProc->setParms($aParm);
 			$sRst = $this->_oProc->run();
+			$this->_aBench["code_end"] = time();
 
+			$this->_aBench["code_eval_start"] = time();
 			// if its created on the memory ...
 			if(is_null($sOut))
 				eval($sRst);
@@ -155,6 +167,7 @@
 				}
 				require_once($sOut);	
 			}	
+			$this->_aBench["code_eval_end"] = time();
 
 			// include the generated class	
 			$oReport = new $this->_sClassName;
@@ -164,6 +177,7 @@
 
 			// run the generated class
 			$this->_sXMLOutputFile = $oReport->run($this->_sXMLOutputFile,$this->_aEnv);
+			$this->_aBench = array_merge($this->_aBench,$oReport->getBenchmarks());
 
 			// check if the XML file exists, we need data!
 			if(!file_exists($this->_sXMLOutputFile)){
@@ -176,7 +190,7 @@
 				Now we have a XML file with the report contents ... what to to with it???
 				Let's call the output plugin!
 			*/	
-					
+
 			//	if there is no one, create a new default plugin
 			$oOut = null;
 			if(is_null($this->_oOutputPlugin)) {
@@ -197,9 +211,31 @@
 
 			// run 	
 			$oOut->run();
+			$this->_aBench["output_end"] = time();
+			$this->_aBench["report_start"] = $iReportStart;
+			$this->_aBench["report_end"] = time();		
 			return $this->_sXMLOutputFile;
 		}
 
+		/******************************************************************************
+		*	Return a (or all) benchmark index.														*
+		******************************************************************************/
+		function getBenchmark($sId=null){
+			if(!$sId)
+				return $this->_aBench;
+			return $this->_aBench[$sId];
+		}
+		
+		/******************************************************************************
+		*	Set the page size (overrides XML value)												*
+		******************************************************************************/
+		function setPageSize($iSize=50){
+			$this->_iPageSize=$iSize;
+		}
+		function getPageSize(){
+			return $this->_iPageSize;
+		}
+
 		/******************************************************************************
 		*																										*
 		*	Set the XML file path																		*
@@ -446,6 +482,14 @@
 			return $this->_sNoDataMsg;
 		}
 
+		function setNoDataFunc($sFunc=""){
+			$this->_sNoDataFunc=$sFunc;
+		}
+
+		function getNoDataFunc(){
+			return $this->_sNoDataFunc;
+		}
+
 		/******************************************************************************
 		*																										*
 		*	Create the output plugin																	*
