@@ -12,7 +12,7 @@
 		var $_iFILE	  = 1;
 		var $_sFile;
 		var $_fHandle;
-		var $_sName;
+		var $_sName = null;
 		var $_sTag;
 		var $_bOpen;
 		var $_iWidth;
@@ -22,6 +22,7 @@
 		var $_sAlign;
 		var $_oGroups;
 		var $_oDoc;		// document layer
+		var $_sClass;	// page class
 
 		function PHPReportPage($sXMLOutputFile=null) {
 			$this->_sTemp			 = getPHPReportsTmpPath();
@@ -47,6 +48,7 @@
 			$this->_sFile			 = $sXMLOutputFile;
 			$this->_bReprintHeader= true;
 			$this->_oDoc			 = null;
+			$this->_sClass			 = null;
 			$this->createFileName();
 		}
 
@@ -58,6 +60,14 @@
 			$this->_oGroups=&$oGroups_;
 		}
 
+		function setClass($sClass_=null){
+			$this->_sClass=$sClass_;
+		}
+		
+		function getClass(){
+			return $this->_sClass;
+		}
+		
 		function setWidth($iWidth_=800) {
 			$this->_iWidth=$iWidth_;
 		}
@@ -145,7 +155,8 @@
 			if($this->isDebugging())
 				print "PAGE:printRow:".$sRow_."<br>";
 
-			$this->_iBcount++;
+			if($bCount_)
+				$this->_iBcount++;
 			$this->_iRow+=($bCount_?1:0);
 			$this->output($sRow_);
 
@@ -159,7 +170,8 @@
 			}
 
 			// check if have a page break here
-			if($this->_iRow+$this->getFooterSize()>$this->_iSize) 
+			if($this->_iSize>0 &&
+				$this->_iRow+$this->getFooterSize()>$this->_iSize) 
 				$this->eventHandler(PAGE_CLOSE);
 		}
 
@@ -171,6 +183,14 @@
 			return $this->_iPageNum;
 		}
 
+		/**
+		 * Set the page number
+		 */
+		function setPageNum($iNum_=0){
+			$this->_iPageNum=$iNum_;
+			return $this->_iPageNum;
+		}
+
 		function &getPage() {
 			return $this;
 		}
@@ -223,8 +243,8 @@
 			$this->_fHandle=fopen($this->_sFile,"w");
 			if(!$this->_fHandle){
 				exit("<br/><b>ERROR!</b><br/>".
-					  "PHPReports could not create the XML file with your data to make your report ".
-					  "runs. Please check if the web server user have rights to write ".
+				     "PHPReports could not create the XML file (".$this->_sFile.") with your data to make your report ".
+			        "runs. Please check if the web server user have rights to write ".
 					  "in your temporary directory. Script aborted.");
 			}
 		}
@@ -294,6 +314,7 @@
 			$sTag	.= ($this->_iCellPadding>=0?" PA=\"".$this->_iCellPadding."\"":"");
 			$sTag	.= ($this->_iCellSpacing>=0?" SP=\"".$this->_iCellSpacing."\"":"");
 			$sTag	.= ($this->_iBorder>0?" BO=\"".$this->_iBorder."\"":"");
+			$sTag .= (!is_null($this->_sClass)?" CL=\"".$this->_sClass."\"":"");
 			$sTag .= ">\n";
 			return $sTag;
 		}
